<?php

namespace Drupal\entity_reference_delete_check\Dto;

/**
 * This data transfer object includes information about entity usages.
 */
class UsageResult {

  /**
   * The usages of the entity in entity reference fields.
   *
   * This is a three-dimensional array.
   * The key of the first dimension is the entity type id.
   * The key of the second dimension is the bundle name.
   * The key of the third dimension is the field name.
   *
   * @var \Drupal\Core\Field\EntityReferenceFieldItemListInterface[][][]
   */
  public readonly array $entityReferenceFields;

  /**
   * Construct a usage result.
   *
   * @param \Drupal\Core\Field\EntityReferenceFieldItemListInterface[][][] $entity_reference_fields
   *   see {@see \Drupal\entity_reference_delete_check\Dto\UsageResult::$entityReferenceFields}.
   */
  public function __construct(array $entity_reference_fields) {
    $this->entityReferenceFields = $entity_reference_fields;
  }

  /**
   * Check whether usages exist or not.
   */
  public function isEmpty(): bool {
    return !$this->entityReferenceFields;
  }

}
